"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const connection_1 = require("../jsonrpc2/connection");
const protocol_1 = require("../protocol");
function createConnection(transports, errorHandler, closeHandler, logger, strategy) {
    const connection = connection_1.createMessageConnection(transports, logger, strategy);
    if (errorHandler) {
        connection.onError(data => errorHandler(data[0], data[1], data[2]));
    }
    if (closeHandler) {
        connection.onClose(closeHandler);
    }
    return {
        listen: () => connection.listen(),
        sendRequest: (type, ...params) => connection.sendRequest(typeof type === 'string' ? type : type.method, ...params),
        onRequest: (type, handler) => connection.onRequest(typeof type === 'string' ? type : type.method, handler),
        sendNotification: (type, params) => connection.sendNotification(typeof type === 'string' ? type : type.method, params),
        onNotification: (type, handler) => connection.onNotification(typeof type === 'string' ? type : type.method, handler),
        initialize: (params) => connection.sendRequest(protocol_1.InitializeRequest.type, backcompatAddRootUri(params)),
        shutdown: () => connection.sendRequest(protocol_1.ShutdownRequest.type, undefined),
        exit: () => connection.sendNotification(protocol_1.ExitNotification.type),
        trace: (value, tracer, sendNotification = false) => connection.trace(value, tracer, sendNotification),
        unsubscribe: () => connection.unsubscribe(),
    };
}
exports.createConnection = createConnection;
/** Adds a rootUri property with the same value as the root for backcompat with LSP. */
function backcompatAddRootUri(params) {
    ;
    params.rootUri = params.root;
    return params;
}
//# sourceMappingURL=connection.js.map