import { Message, ResponseError } from '../jsonrpc2/messages';
import { InitializeError } from '../protocol';
/**
 * Called by the client when initialization fails to determine how to proceed.
 *
 * @returns true to attempt reinitialization, false otherwise
 */
export declare type InitializationFailedHandler = (error: ResponseError<InitializeError> | Error | any) => boolean | Promise<boolean>;
/**
 * A pluggable error handler that is invoked when the connection encounters an error or is closed.
 */
export interface ErrorHandler {
    /**
     * An error has occurred while writing or reading from the connection.
     *
     * @param error - the error received
     * @param message - the message that was being delivered, if known
     * @param count - how many times this error has occurred (reset after success)
     */
    error(error: Error, message: Message | undefined, count: number | undefined): ErrorAction;
    /**
     * The connection to the server got closed.
     */
    closed(): CloseAction | Promise<CloseAction>;
}
/** An action to be performed when the connection is producing errors. */
export declare enum ErrorAction {
    /** Continue running the server. */
    Continue = 1,
    /** Shut down the server. */
    ShutDown = 2
}
/** An action to be performed when the connection to a server is closed. */
export declare enum CloseAction {
    /** Don't reconnect to the server. The connection will remain closed. */
    DoNotReconnect = 1,
    /** Reconnect to the server. */
    Reconnect = 2
}
/** The default error handler. */
export declare class DefaultErrorHandler implements ErrorHandler {
    private reconnects;
    error(_error: Error, _message: Message, count: number): ErrorAction;
    closed(): CloseAction;
}
