"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** An action to be performed when the connection is producing errors. */
var ErrorAction;
(function (ErrorAction) {
    /** Continue running the server. */
    ErrorAction[ErrorAction["Continue"] = 1] = "Continue";
    /** Shut down the server. */
    ErrorAction[ErrorAction["ShutDown"] = 2] = "ShutDown";
})(ErrorAction = exports.ErrorAction || (exports.ErrorAction = {}));
/** An action to be performed when the connection to a server is closed. */
var CloseAction;
(function (CloseAction) {
    /** Don't reconnect to the server. The connection will remain closed. */
    CloseAction[CloseAction["DoNotReconnect"] = 1] = "DoNotReconnect";
    /** Reconnect to the server. */
    CloseAction[CloseAction["Reconnect"] = 2] = "Reconnect";
})(CloseAction = exports.CloseAction || (exports.CloseAction = {}));
/** The default error handler. */
class DefaultErrorHandler {
    constructor() {
        this.reconnects = [];
    }
    error(_error, _message, count) {
        if (count && count <= 3) {
            return ErrorAction.Continue;
        }
        return ErrorAction.ShutDown;
    }
    closed() {
        this.reconnects.push(Date.now());
        if (this.reconnects.length < 5) {
            return CloseAction.Reconnect;
        }
        else {
            const diff = this.reconnects[this.reconnects.length - 1] - this.reconnects[0];
            if (diff <= 3 * 60 * 1000) {
                // The client reconnected 5 times in the last 3 minutes. Do not attempt to reconnect again.
                return CloseAction.DoNotReconnect;
            }
            else {
                this.reconnects.shift();
                return CloseAction.Reconnect;
            }
        }
    }
}
exports.DefaultErrorHandler = DefaultErrorHandler;
//# sourceMappingURL=errorHandler.js.map