"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const v4_1 = __importDefault(require("uuid/v4"));
const protocol_1 = require("../../protocol");
const common_1 = require("./common");
/**
 * Support for the commands executed on the server by the client (workspace/executeCommand requests to the server).
 */
class ExecuteCommandFeature {
    constructor(client, registry) {
        this.client = client;
        this.registry = registry;
        this.commands = new Map();
    }
    get messages() {
        return protocol_1.ExecuteCommandRequest.type;
    }
    fillClientCapabilities(capabilities) {
        common_1.ensure(common_1.ensure(capabilities, 'workspace'), 'executeCommand').dynamicRegistration = true;
    }
    initialize(capabilities) {
        if (!capabilities.executeCommandProvider) {
            return;
        }
        this.register(this.messages, {
            id: v4_1.default(),
            registerOptions: Object.assign({}, capabilities.executeCommandProvider),
        });
    }
    register(_message, data) {
        const existing = this.commands.has(data.id);
        if (existing) {
            throw new Error(`registration already exists with ID ${data.id}`);
        }
        const sub = new rxjs_1.Subscription();
        for (const command of data.registerOptions.commands) {
            try {
                sub.add(this.registry.registerCommand({
                    command,
                    run: (...args) => this.client.sendRequest(protocol_1.ExecuteCommandRequest.type, {
                        command,
                        arguments: args,
                    }),
                }));
            }
            catch (err) {
                // Unregister commands that were successfully registered if any of them fails, so that this invocation
                // is atomic (all-or-none).
                sub.unsubscribe();
                throw err;
            }
        }
        this.commands.set(data.id, sub);
    }
    unregister(id) {
        const sub = this.commands.get(id);
        if (!sub) {
            throw new Error(`no registration with ID ${id}`);
        }
        if (sub) {
            sub.unsubscribe();
        }
        this.commands.delete(id);
    }
    unregisterAll() {
        for (const sub of this.commands.values()) {
            sub.unsubscribe();
        }
        this.commands.clear();
    }
}
exports.ExecuteCommandFeature = ExecuteCommandFeature;
//# sourceMappingURL=command.js.map