import { Observable } from 'rxjs';
import { MessageType as RPCMessageType } from '../../jsonrpc2/messages';
import { ClientCapabilities, ConfigurationCascade, ConfigurationUpdateParams, InitializeParams, ServerCapabilities } from '../../protocol';
import { Client } from '../client';
import { DynamicFeature, RegistrationData, StaticFeature } from './common';
/**
 * Support for configuration settings managed by the client (workspace/didChangeConfiguration notifications to the
 * server).
 *
 * @template C configuration cascade type
 */
export declare class ConfigurationChangeNotificationFeature<C extends ConfigurationCascade> implements DynamicFeature<undefined> {
    private client;
    private configurationCascade;
    private subscriptionsByID;
    constructor(client: Client, configurationCascade: Observable<C>);
    readonly messages: import("../../jsonrpc2/messages").NotificationType<import("../../protocol/configuration").DidChangeConfigurationParams, import("../../protocol/configuration").DidChangeConfigurationRegistrationOptions>;
    fillInitializeParams(params: InitializeParams): void;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(capabilities: ServerCapabilities): void;
    register(message: RPCMessageType, data: RegistrationData<undefined>): void;
    unregister(id: string): void;
    unregisterAll(): void;
}
/**
 * Support for the server requesting the client's configuration (workspace/configuration request to the client).
 *
 * @template C configuration cascade type
 */
export declare class ConfigurationFeature<C extends ConfigurationCascade> implements StaticFeature {
    private client;
    private configurationCascade;
    constructor(client: Client, configurationCascade: Observable<C>);
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(): void;
    private getConfiguration;
}
/**
 * Support for the server updating the client's configuration (configuration/update request to the
 * client).
 */
export declare class ConfigurationUpdateFeature implements StaticFeature {
    private client;
    /** Called when the client receives a configuration/update request. */
    private update;
    constructor(client: Client, 
    /** Called when the client receives a configuration/update request. */
    update: (params: ConfigurationUpdateParams) => Promise<void>);
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(): void;
}
