import { Observable, Unsubscribable } from 'rxjs';
import { TextDocumentIdentifier } from 'vscode-languageserver-types';
import { ProvideTextDocumentDecorationSignature } from '../../environment/providers/decoration';
import { FeatureProviderRegistry } from '../../environment/providers/registry';
import { ClientCapabilities, ServerCapabilities } from '../../protocol';
import { TextDocumentDecoration } from '../../protocol/decoration';
import { NextSignature } from '../../types/middleware';
import { Client } from '../client';
import { Feature } from './common';
export declare type ProvideTextDocumentDecorationMiddleware = NextSignature<TextDocumentIdentifier, Observable<TextDocumentDecoration[] | null>>;
/**
 * Support for text document decorations published by the server (textDocument/publishDecorations notifications
 * from the server).
 */
export declare class TextDocumentDecorationFeature extends Feature<undefined> {
    private registry;
    /** Map of document URI to its decorations (last published by the server). */
    private decorations;
    constructor(client: Client, registry: FeatureProviderRegistry<undefined, ProvideTextDocumentDecorationSignature>);
    readonly messages: import("../../jsonrpc2/messages").NotificationType<import("../../protocol/decoration").TextDocumentPublishDecorationsParams, import("../../protocol/textDocument").TextDocumentRegistrationOptions>;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(capabilities: ServerCapabilities): void;
    protected registerProvider(): Unsubscribable;
    private getDecorationsSubject;
}
