"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const v4_1 = __importDefault(require("uuid/v4"));
const decoration_1 = require("../../protocol/decoration");
const common_1 = require("./common");
/**
 * Support for text document decorations published by the server (textDocument/publishDecorations notifications
 * from the server).
 */
class TextDocumentDecorationFeature extends common_1.Feature {
    constructor(client, registry) {
        super(client);
        this.registry = registry;
        /** Map of document URI to its decorations (last published by the server). */
        this.decorations = new Map();
        this.messages = decoration_1.TextDocumentPublishDecorationsNotification.type;
    }
    fillClientCapabilities(capabilities) {
        common_1.ensure(capabilities, 'decoration');
    }
    initialize(capabilities) {
        if (!capabilities.decorationProvider) {
            return;
        }
        this.register(this.messages, { id: v4_1.default(), registerOptions: undefined });
        // TODO(sqs): no way to unregister this
        this.client.onNotification(decoration_1.TextDocumentPublishDecorationsNotification.type, params => {
            this.getDecorationsSubject(params.textDocument, params.decorations);
        });
    }
    registerProvider() {
        const client = this.client;
        const provideTextDocumentDecoration = textDocument => this.getDecorationsSubject(textDocument);
        const middleware = client.options.middleware.provideTextDocumentDecoration;
        return this.registry.registerProvider(undefined, (textDocument) => middleware
            ? middleware(textDocument, provideTextDocumentDecoration)
            : provideTextDocumentDecoration(textDocument));
    }
    getDecorationsSubject(textDocument, value) {
        let subject = this.decorations.get(textDocument.uri);
        if (!subject) {
            subject = new rxjs_1.BehaviorSubject(value || null);
            this.decorations.set(textDocument.uri, subject);
        }
        if (value !== undefined) {
            subject.next(value);
        }
        return subject;
    }
}
exports.TextDocumentDecorationFeature = TextDocumentDecorationFeature;
//# sourceMappingURL=decoration.js.map