"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const v4_1 = __importDefault(require("uuid/v4"));
const vscode_languageserver_types_1 = require("vscode-languageserver-types");
const protocol_1 = require("../../protocol");
const common_1 = require("./common");
/**
 * Support for hover messages (textDocument/hover requests to the server).
 */
class TextDocumentHoverFeature extends common_1.Feature {
    constructor(client, registry) {
        super(client);
        this.registry = registry;
        this.messages = protocol_1.HoverRequest.type;
    }
    fillClientCapabilities(capabilities) {
        const hoverCapability = common_1.ensure(common_1.ensure(capabilities, 'textDocument'), 'hover');
        hoverCapability.dynamicRegistration = true;
        hoverCapability.contentFormat = [vscode_languageserver_types_1.MarkupKind.Markdown, vscode_languageserver_types_1.MarkupKind.PlainText];
    }
    initialize(capabilities, documentSelector) {
        if (!capabilities.hoverProvider || !documentSelector) {
            return;
        }
        this.register(this.messages, {
            id: v4_1.default(),
            registerOptions: { documentSelector },
        });
    }
    registerProvider(options) {
        const client = this.client;
        const provideTextDocumentHover = params => client.sendRequest(protocol_1.HoverRequest.type, params);
        const middleware = client.options.middleware.provideTextDocumentHover;
        return this.registry.registerProvider(options, (params) => middleware ? middleware(params, provideTextDocumentHover) : provideTextDocumentHover(params));
    }
}
exports.TextDocumentHoverFeature = TextDocumentHoverFeature;
//# sourceMappingURL=hover.js.map