import { MessageActionItem, ShowInputParams, ShowMessageParams, ShowMessageRequestParams } from '../../protocol';
import { Client } from '../client';
import { StaticFeature } from './common';
/**
 * Support for server messages intended for display to the user (window/showMessages notifications and
 * window/showMessageRequest requests from the server).
 */
export declare class WindowShowMessageFeature implements StaticFeature {
    private client;
    /** Called when the client receives a window/showMessage notification. */
    private showMessage;
    /**
     * Called when the client receives a window/showMessageRequest request and expected to return a promise
     * that resolves to the selected action.
     */
    private showMessageRequest;
    /**
     * Called when the client receives a window/showInput request and expected to return a promise that
     * resolves to the user's input.
     */
    private showInput;
    constructor(client: Client, 
    /** Called when the client receives a window/showMessage notification. */
    showMessage: (params: ShowMessageParams) => void, 
    /**
     * Called when the client receives a window/showMessageRequest request and expected to return a promise
     * that resolves to the selected action.
     */
    showMessageRequest: (params: ShowMessageRequestParams) => Promise<MessageActionItem | null>, 
    /**
     * Called when the client receives a window/showInput request and expected to return a promise that
     * resolves to the user's input.
     */
    showInput: (params: ShowInputParams) => Promise<string | null>);
    initialize(): void;
}
