"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const protocol_1 = require("../../protocol");
/**
 * Support for server messages intended for display to the user (window/showMessages notifications and
 * window/showMessageRequest requests from the server).
 */
class WindowShowMessageFeature {
    constructor(client, 
    /** Called when the client receives a window/showMessage notification. */
    showMessage, 
    /**
     * Called when the client receives a window/showMessageRequest request and expected to return a promise
     * that resolves to the selected action.
     */
    showMessageRequest, 
    /**
     * Called when the client receives a window/showInput request and expected to return a promise that
     * resolves to the user's input.
     */
    showInput) {
        this.client = client;
        this.showMessage = showMessage;
        this.showMessageRequest = showMessageRequest;
        this.showInput = showInput;
    }
    initialize() {
        // TODO(sqs): no way to unregister these
        this.client.onNotification(protocol_1.ShowMessageNotification.type, this.showMessage);
        this.client.onRequest(protocol_1.ShowMessageRequest.type, this.showMessageRequest);
        this.client.onRequest(protocol_1.ShowInputRequest.type, this.showInput);
    }
}
exports.WindowShowMessageFeature = WindowShowMessageFeature;
//# sourceMappingURL=message.js.map