"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const util_1 = require("../util");
const context_1 = require("./context/context");
/** An empty CXP environment. */
exports.EMPTY_ENVIRONMENT = {
    root: null,
    component: null,
    extensions: null,
    configuration: { merged: {} },
    context: context_1.EMPTY_CONTEXT,
};
/** An ObservableEnvironment that always represents the empty environment and never emits changes. */
exports.EMPTY_OBSERVABLE_ENVIRONMENT = {
    environment: rxjs_1.of(exports.EMPTY_ENVIRONMENT),
    root: rxjs_1.of(null),
    component: rxjs_1.of(null),
    textDocument: rxjs_1.of(null),
    configuration: rxjs_1.of({}),
    context: rxjs_1.of(context_1.EMPTY_CONTEXT),
};
/**
 * Helper function for creating an ObservableEnvironment from the raw environment Observable.
 *
 * @template X extension type
 * @template C configuration cascade type
 */
function createObservableEnvironment(environment) {
    const root = environment.pipe(operators_1.map(({ root }) => root), operators_1.distinctUntilChanged());
    const component = environment.pipe(operators_1.map(({ component }) => component), operators_1.distinctUntilChanged((a, b) => util_1.isEqual(a, b)));
    const textDocument = component.pipe(operators_1.map(component => (component ? component.document : null)), operators_1.distinctUntilChanged((a, b) => util_1.isEqual(a, b)));
    const configuration = environment.pipe(operators_1.map(({ configuration }) => configuration), operators_1.distinctUntilChanged((a, b) => util_1.isEqual(a, b)));
    const context = environment.pipe(operators_1.map(({ context }) => context), operators_1.distinctUntilChanged((a, b) => util_1.isEqual(a, b)));
    return {
        environment,
        root,
        component,
        textDocument,
        configuration,
        context,
    };
}
exports.createObservableEnvironment = createObservableEnvironment;
//# sourceMappingURL=environment.js.map