"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const registry_1 = require("./registry");
const util_1 = require("./util");
/** Provides text document decorations from all extensions. */
class TextDocumentDecorationProviderRegistry extends registry_1.FeatureProviderRegistry {
    getDecorations(params) {
        return getDecorations(this.providers, params);
    }
}
exports.TextDocumentDecorationProviderRegistry = TextDocumentDecorationProviderRegistry;
/**
 * Returns an observable that emits all decorations whenever any of the last-emitted set of providers emits
 * decorations.
 *
 * Most callers should use TextDocumentDecorationProviderRegistry, which uses the registered decoration providers.
 */
function getDecorations(providers, params) {
    return providers
        .pipe(operators_1.switchMap(providers => {
        if (providers.length === 0) {
            return [null];
        }
        return rxjs_1.combineLatest(providers.map(provider => provider(params)));
    }))
        .pipe(operators_1.map(util_1.flattenAndCompact));
}
exports.getDecorations = getDecorations;
//# sourceMappingURL=decoration.js.map