"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const hover_1 = require("../../types/hover");
const registry_1 = require("./registry");
/** Provides hovers from all extensions. */
class TextDocumentHoverProviderRegistry extends registry_1.FeatureProviderRegistry {
    getHover(params) {
        return getHover(this.providers, params);
    }
}
exports.TextDocumentHoverProviderRegistry = TextDocumentHoverProviderRegistry;
/**
 * Returns an observable that emits all providers' hovers whenever any of the last-emitted set of providers emits
 * hovers.
 *
 * Most callers should use TextDocumentHoverProviderRegistry's getHover method, which uses the registered hover
 * providers.
 */
function getHover(providers, params) {
    return providers
        .pipe(operators_1.switchMap(providers => {
        if (providers.length === 0) {
            return [[null]];
        }
        return rxjs_1.combineLatest(providers.map(provider => rxjs_1.from(provider(params))));
    }))
        .pipe(operators_1.map(hover_1.HoverMerged.from));
}
exports.getHover = getHover;
//# sourceMappingURL=hover.js.map