"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const v4_1 = __importDefault(require("uuid/v4"));
const command_1 = require("../../environment/providers/command");
const protocol_1 = require("../../protocol");
/**
 * Creates the CXP extension API's {@link CXP#commands} value.
 *
 * @param ext The CXP extension API handle.
 * @return The {@link CXP#commands} value.
 */
function createExtCommands(ext) {
    // TODO: move CommandRegistry to somewhere general since it's now used by the controller AND extension
    const commandRegistry = new command_1.CommandRegistry();
    ext.rawConnection.onRequest(protocol_1.ExecuteCommandRequest.type, params => commandRegistry.executeCommand(params));
    return {
        register: (command, run) => {
            const subscription = new rxjs_1.Subscription();
            const id = v4_1.default();
            subscription.add(commandRegistry.registerCommand({ command, run }));
            ext.rawConnection
                .sendRequest(protocol_1.RegistrationRequest.type, {
                registrations: [
                    {
                        id,
                        method: protocol_1.ExecuteCommandRequest.type.method,
                        registerOptions: { commands: [command] },
                    },
                ],
            })
                .catch(err => console.error(err));
            subscription.add(() => {
                ext.rawConnection
                    .sendRequest(protocol_1.UnregistrationRequest.type, {
                    unregisterations: [{ id, method: protocol_1.ExecuteCommandRequest.type.method }],
                })
                    .catch(err => console.error(err));
            });
            return subscription;
        },
    };
}
exports.createExtCommands = createExtCommands;
//# sourceMappingURL=commands.js.map