"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const messages_1 = require("../jsonrpc2/messages");
// Copied from vscode-jsonrpc to avoid adding extraneous dependencies.
var Trace;
(function (Trace) {
    Trace[Trace["Off"] = 0] = "Off";
    Trace[Trace["Messages"] = 1] = "Messages";
    Trace[Trace["Verbose"] = 2] = "Verbose";
})(Trace = exports.Trace || (exports.Trace = {}));
(function (Trace) {
    function fromString(value) {
        value = value.toLowerCase();
        switch (value) {
            // tslint:disable:no-unnecessary-qualifier
            case 'off':
                return Trace.Off;
            case 'messages':
                return Trace.Messages;
            case 'verbose':
                return Trace.Verbose;
            default:
                return Trace.Off;
            // tslint:enable:no-unnecessary-qualifier
        }
    }
    Trace.fromString = fromString;
    function toString(value) {
        switch (value) {
            // tslint:disable:no-unnecessary-qualifier
            case Trace.Off:
                return 'off';
            case Trace.Messages:
                return 'messages';
            case Trace.Verbose:
                return 'verbose';
            default:
                return 'off';
            // tslint:enable:no-unnecessary-qualifier
        }
    }
    Trace.toString = toString;
})(Trace = exports.Trace || (exports.Trace = {}));
var SetTraceNotification;
(function (SetTraceNotification) {
    SetTraceNotification.type = new messages_1.NotificationType('$/setTraceNotification');
})(SetTraceNotification = exports.SetTraceNotification || (exports.SetTraceNotification = {}));
var LogTraceNotification;
(function (LogTraceNotification) {
    LogTraceNotification.type = new messages_1.NotificationType('$/logTraceNotification');
})(LogTraceNotification = exports.LogTraceNotification || (exports.LogTraceNotification = {}));
/** A tracer that implements the Tracer interface with noop methods. */
exports.noopTracer = {
    log: () => void 0,
    requestSent: () => void 0,
    requestReceived: () => void 0,
    notificationSent: () => void 0,
    notificationReceived: () => void 0,
    responseSent: () => void 0,
    responseCanceled: () => void 0,
    responseReceived: () => void 0,
    unknownResponseReceived: () => void 0,
};
/** A tracer that implements the Tracer interface with console API calls, intended for a web browser. */
class BrowserConsoleTracer {
    constructor(name) {
        this.name = name;
    }
    prefix(level, label, title) {
        let color;
        let backgroundColor;
        if (level === 'info') {
            color = '#000';
            backgroundColor = '#eee';
        }
        else {
            color = 'white';
            backgroundColor = 'red';
        }
        return [
            '%c%s%c %s%c%s%c',
            `font-weight:bold;background-color:#d8f7ff;color:black`,
            this.name,
            '',
            label,
            `background-color:${backgroundColor};color:${color};font-weight:bold`,
            title,
            '',
        ];
    }
    log(message, details) {
        if (details) {
            ;
            console.groupCollapsed(...this.prefix('info', 'log', ''), message);
            console.log(details);
            console.groupEnd();
        }
        else {
            console.log(...this.prefix('info', 'log', ''), message);
        }
    }
    requestSent(message) {
        console.log(...this.prefix('info', `◀◀ sent request #${message.id}: `, message.method), message.params);
    }
    requestReceived(message) {
        console.log(...this.prefix('info', `▶▶ recv request #${message.id}: `, message.method), message.params);
    }
    notificationSent(message) {
        console.log(...this.prefix('info', `◀◀ sent notif: `, message.method), message.params);
    }
    notificationReceived(message) {
        console.log(...this.prefix('info', `▶▶ recv notif: `, message.method), message.params);
    }
    responseSent(message, request, startTime) {
        const prefix = this.prefix(message.error ? 'error' : 'info', `◀▶ sent response #${message.id}: `, typeof request === 'string' ? request : request.method);
        console.groupCollapsed(...prefix);
        if (message.error) {
            console.log('Error:', message.error);
        }
        else {
            console.log('Result:', message.result);
        }
        console.log('Request:', request);
        console.log('Duration: %d msec', Date.now() - startTime);
        console.groupEnd();
    }
    responseCanceled(_message, request, _cancelMessage) {
        console.log(...this.prefix('info', '× cancel: ', request.method));
    }
    responseReceived(message, request, startTime) {
        const prefix = this.prefix(message.error ? 'error' : 'info', `◀▶ recv response #${message.id}: `, typeof request === 'string' ? request : request.method);
        if (typeof request === 'string') {
            console.log(...prefix, message.error || message.result);
        }
        else {
            ;
            console.groupCollapsed(...prefix);
            if (message.error) {
                console.log('Error:', message.error);
            }
            else {
                console.log('Result:', message.result);
            }
            console.log('Request:', request);
            console.log('Duration: %d msec', Date.now() - startTime);
            console.groupEnd();
        }
    }
    unknownResponseReceived(message) {
        console.log(...this.prefix('error', 'UNKNOWN', ''), message);
    }
}
exports.BrowserConsoleTracer = BrowserConsoleTracer;
//# sourceMappingURL=trace.js.map