import { Event } from './events';
import { Message } from './messages';
export declare type DataCallback = (data: Message) => void;
export interface PartialMessageInfo {
    readonly messageToken: number;
    readonly waitingTime: number;
}
export interface MessageReader {
    readonly onError: Event<Error>;
    readonly onClose: Event<void>;
    readonly onPartialMessage: Event<PartialMessageInfo>;
    listen(callback: DataCallback): void;
    unsubscribe(): void;
}
export declare namespace MessageReader {
    function is(value: any): value is MessageReader;
}
export declare abstract class AbstractMessageReader {
    private errorEmitter;
    private closeEmitter;
    private partialMessageEmitter;
    constructor();
    unsubscribe(): void;
    readonly onError: Event<Error>;
    protected fireError(error: any): void;
    readonly onClose: Event<void>;
    protected fireClose(): void;
    readonly onPartialMessage: Event<PartialMessageInfo>;
    protected firePartialMessage(info: PartialMessageInfo): void;
    private asError;
}
export interface MessageWriter {
    readonly onError: Event<[Error, Message | undefined, number | undefined]>;
    readonly onClose: Event<void>;
    write(msg: Message): void;
    unsubscribe(): void;
}
export declare namespace MessageWriter {
    function is(value: any): value is MessageWriter;
}
export declare abstract class AbstractMessageWriter {
    private errorEmitter;
    private closeEmitter;
    unsubscribe(): void;
    readonly onError: Event<[Error, Message | undefined, number | undefined]>;
    protected fireError(error: any, message?: Message, count?: number): void;
    readonly onClose: Event<void>;
    protected fireClose(): void;
    private asError;
}
