"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
const events_1 = require("./events");
var MessageReader;
(function (MessageReader) {
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unbound-method
            util_1.isFunction(candidate.listen) &&
            // tslint:disable-next-line:no-unbound-method
            util_1.isFunction(candidate.unsubscribe) &&
            util_1.isFunction(candidate.onError) &&
            util_1.isFunction(candidate.onClose) &&
            util_1.isFunction(candidate.onPartialMessage));
    }
    MessageReader.is = is;
})(MessageReader = exports.MessageReader || (exports.MessageReader = {}));
class AbstractMessageReader {
    constructor() {
        this.errorEmitter = new events_1.Emitter();
        this.closeEmitter = new events_1.Emitter();
        this.partialMessageEmitter = new events_1.Emitter();
    }
    unsubscribe() {
        this.errorEmitter.unsubscribe();
        this.closeEmitter.unsubscribe();
    }
    get onError() {
        return this.errorEmitter.event;
    }
    fireError(error) {
        this.errorEmitter.fire(this.asError(error));
    }
    get onClose() {
        return this.closeEmitter.event;
    }
    fireClose() {
        this.closeEmitter.fire(undefined);
    }
    get onPartialMessage() {
        return this.partialMessageEmitter.event;
    }
    firePartialMessage(info) {
        this.partialMessageEmitter.fire(info);
    }
    asError(error) {
        if (error instanceof Error) {
            return error;
        }
        return new Error(`Reader received error. Reason: ${typeof error.message === 'string' ? error.message : 'unknown'}`);
    }
}
exports.AbstractMessageReader = AbstractMessageReader;
var MessageWriter;
(function (MessageWriter) {
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unbound-method
            util_1.isFunction(candidate.unsubscribe) &&
            util_1.isFunction(candidate.onClose) &&
            util_1.isFunction(candidate.onError) &&
            // tslint:disable-next-line:no-unbound-method
            util_1.isFunction(candidate.write));
    }
    MessageWriter.is = is;
})(MessageWriter = exports.MessageWriter || (exports.MessageWriter = {}));
class AbstractMessageWriter {
    constructor() {
        this.errorEmitter = new events_1.Emitter();
        this.closeEmitter = new events_1.Emitter();
    }
    unsubscribe() {
        this.errorEmitter.unsubscribe();
        this.closeEmitter.unsubscribe();
    }
    get onError() {
        return this.errorEmitter.event;
    }
    fireError(error, message, count) {
        this.errorEmitter.fire([this.asError(error), message, count]);
    }
    get onClose() {
        return this.closeEmitter.event;
    }
    fireClose() {
        this.closeEmitter.fire(undefined);
    }
    asError(error) {
        if (error instanceof Error) {
            return error;
        }
        return new Error(`Writer received error. Reason: ${typeof error.message === 'string' ? error.message : 'unknown'}`);
    }
}
exports.AbstractMessageWriter = AbstractMessageWriter;
//# sourceMappingURL=transport.js.map