"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const client_1 = require("../client/client");
/** Reports the client's current state. */
function getClientState(client) {
    let clientState;
    client.state
        .pipe(operators_1.first())
        .subscribe(state => (clientState = state))
        .unsubscribe();
    if (clientState === undefined) {
        // This should never happen, because client.state is implemented by a BehaviorSubject that always has a
        // current value.
        throw new Error('client state is not synchronously available');
    }
    return clientState;
}
exports.getClientState = getClientState;
/**
 * Returns a Promise that resolves when the client enters ClientState.Active and rejects if it enters a client
 * state that indicates an error.
 */
function clientStateIsActive(client) {
    return clientStateIs(client, client_1.ClientState.Active, [
        client_1.ClientState.ActivateFailed,
        client_1.ClientState.ShuttingDown,
        client_1.ClientState.Stopped,
    ]).then(() => void 0);
}
exports.clientStateIsActive = clientStateIsActive;
/**
 * Returns a Promise that resolves when the client enters the given client state and rejects if it enters one of
 * the reject states.
 */
function clientStateIs(client, resolveState, rejectStates = []) {
    return client.state
        .pipe(operators_1.switchMap(state => {
        if (state === resolveState) {
            return [state];
        }
        if (rejectStates.includes(state)) {
            return rxjs_1.throwError(new Error(`client entered reject state ${client_1.ClientState[state]}`));
        }
        return [];
    }), operators_1.first())
        .toPromise();
}
exports.clientStateIs = clientStateIs;
/** Returns a promise that resolves with the value after the given delay (in milliseconds). */
function delayed(value, msec) {
    return new Promise(resolve => {
        setTimeout(() => resolve(value), msec);
    });
}
exports.delayed = delayed;
//# sourceMappingURL=helpers.js.map