"use strict";
/**
 * This file contains (simplified) implementations of Lodash functions. We use these instead of depending on Lodash
 * because depending on it (1) either results in a significantly larger bundle size, if tree-shaking is not enabled
 * (and the npm lodash package is used), or (2) significantly increases the complexity of bundling and executing
 * code, if tree-shaking is enabled (and the npm lodash-es package is used).
 */
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable-next-line:no-unbound-method
const toString = Object.prototype.toString;
/** Reports whether value is a function. */
// tslint:disable-next-line:ban-types
function isFunction(value) {
    return toString.call(value) === '[object Function]';
}
exports.isFunction = isFunction;
/** Flattens the array one level deep. */
function flatten(array) {
    const result = [];
    for (const value of array) {
        if (Array.isArray(value)) {
            result.push(...value);
        }
        else {
            result.push(value);
        }
    }
    return result;
}
exports.flatten = flatten;
/** Removes all falsey values. */
function compact(array) {
    const result = [];
    for (const value of array) {
        if (value) {
            result.push(value);
        }
    }
    return result;
}
exports.compact = compact;
/** Reports whether the two values are equal, using a strict deep comparison. */
function isEqual(a, b) {
    if (a === b) {
        return true;
    }
    // tslint:disable-next-line:triple-equals
    if (!a || !b || (typeof a !== 'object' && typeof b !== 'object')) {
        return a === b;
    }
    return equalObjects(a, b);
}
exports.isEqual = isEqual;
function equalObjects(a, b) {
    const ka = Object.keys(a);
    const kb = Object.keys(b);
    if (ka.length !== kb.length) {
        return false;
    }
    ka.sort();
    kb.sort();
    for (let i = ka.length - 1; i >= 0; i--) {
        if (ka[i] !== kb[i]) {
            return false;
        }
    }
    for (let i = ka.length - 1; i >= 0; i--) {
        const key = ka[i];
        if (!isEqual(a[key], b[key])) {
            return false;
        }
    }
    return typeof a === typeof b;
}
/**
 * Runs f and returns a resolved promise with its value or a rejected promise with its exception,
 * regardless of whether it returns a promise or not.
 */
function tryCatchPromise(f) {
    try {
        return Promise.resolve(f());
    }
    catch (err) {
        return Promise.reject(err);
    }
}
exports.tryCatchPromise = tryCatchPromise;
//# sourceMappingURL=util.js.map