import { Unsubscribable } from 'rxjs';
import { Logger, MessageTransports } from '../jsonrpc2/connection';
import { ConnectionStrategy } from '../jsonrpc2/connectionStrategy';
import { GenericNotificationHandler, GenericRequestHandler, NotificationHandler, RequestHandler } from '../jsonrpc2/handlers';
import { Message, MessageType as RPCMessageType, NotificationType, RequestType } from '../jsonrpc2/messages';
import { Trace, Tracer } from '../jsonrpc2/trace';
import { InitializeParams, InitializeResult } from '../protocol';
export interface Connection extends Unsubscribable {
    listen(): void;
    sendRequest<P, R, E, RO>(type: RequestType<P, R, E, RO>, params: P): Promise<R>;
    sendRequest<R>(method: string, param?: any): Promise<R>;
    sendRequest<R>(type: string | RPCMessageType, ...params: any[]): Promise<R>;
    onRequest<P, R, E, RO>(type: RequestType<P, R, E, RO>, handler: RequestHandler<P, R, E>): void;
    onRequest<R, E>(method: string | RPCMessageType, handler: GenericRequestHandler<R, E>): void;
    sendNotification<P, RO>(type: NotificationType<P, RO>, params?: P): void;
    sendNotification(method: string | RPCMessageType, params?: any): void;
    onNotification<P, RO>(type: NotificationType<P, RO>, handler: NotificationHandler<P>): void;
    onNotification(method: string | RPCMessageType, handler: GenericNotificationHandler): void;
    initialize(params: InitializeParams): Promise<InitializeResult>;
    shutdown(): Promise<void>;
    exit(): void;
    trace(value: Trace, tracer: Tracer, sendNotification?: boolean): void;
}
declare type ConnectionErrorHandler = (error: Error, message: Message | undefined, count: number | undefined) => void;
declare type ConnectionCloseHandler = () => void;
export declare function createConnection(transports: MessageTransports, errorHandler?: ConnectionErrorHandler, closeHandler?: ConnectionCloseHandler, logger?: Logger, strategy?: ConnectionStrategy): Connection;
export {};
