import { createMessageConnection } from '../jsonrpc2/connection';
import { ExitNotification, InitializeRequest, ShutdownRequest } from '../protocol';
export function createConnection(transports, errorHandler, closeHandler, logger, strategy) {
    const connection = createMessageConnection(transports, logger, strategy);
    if (errorHandler) {
        connection.onError(data => errorHandler(data[0], data[1], data[2]));
    }
    if (closeHandler) {
        connection.onClose(closeHandler);
    }
    return {
        listen: () => connection.listen(),
        sendRequest: (type, ...params) => connection.sendRequest(typeof type === 'string' ? type : type.method, ...params),
        onRequest: (type, handler) => connection.onRequest(typeof type === 'string' ? type : type.method, handler),
        sendNotification: (type, params) => connection.sendNotification(typeof type === 'string' ? type : type.method, params),
        onNotification: (type, handler) => connection.onNotification(typeof type === 'string' ? type : type.method, handler),
        initialize: (params) => connection.sendRequest(InitializeRequest.type, backcompatAddRootUri(params)),
        shutdown: () => connection.sendRequest(ShutdownRequest.type, undefined),
        exit: () => connection.sendNotification(ExitNotification.type),
        trace: (value, tracer, sendNotification = false) => connection.trace(value, tracer, sendNotification),
        unsubscribe: () => connection.unsubscribe(),
    };
}
/** Adds a rootUri property with the same value as the root for backcompat with LSP. */
function backcompatAddRootUri(params) {
    ;
    params.rootUri = params.root;
    return params;
}
//# sourceMappingURL=connection.js.map