import { isFunction } from '../../util';
export var DynamicFeature;
(function (DynamicFeature) {
    /** Reports whether the value is a DynamicFeature. */
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.register) &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.unregister) &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.unregisterAll) &&
            candidate.messages !== void 0);
    }
    DynamicFeature.is = is;
})(DynamicFeature || (DynamicFeature = {}));
/** Common base class for client features. */
export class Feature {
    constructor(client) {
        this.client = client;
        this.subscriptionsByID = new Map();
    }
    register(message, data) {
        if (message.method !== this.messages.method) {
            throw new Error(`Register called on wrong feature. Requested ${message.method} but reached feature ${this.messages.method}`);
        }
        if (this.subscriptionsByID.has(data.id)) {
            throw new Error(`registration already exists with ID ${data.id}`);
        }
        this.subscriptionsByID.set(data.id, this.registerProvider(data.registerOptions));
    }
    unregister(id) {
        const sub = this.subscriptionsByID.get(id);
        if (!sub) {
            throw new Error(`no registration with ID ${id}`);
        }
        this.subscriptionsByID.delete(id);
    }
    unregisterAll() {
        for (const sub of this.subscriptionsByID.values()) {
            sub.unsubscribe();
        }
        this.subscriptionsByID.clear();
    }
}
export function ensure(target, key) {
    if (target[key] === void 0) {
        target[key] = {};
    }
    return target[key];
}
//# sourceMappingURL=common.js.map