import { ContextUpdateNotification } from '../../protocol/context';
/**
 * Support for context set by the server (context/update notifications from the server).
 */
export class ContextFeature {
    constructor(client, setContext) {
        this.client = client;
        this.setContext = setContext;
        /**
         * Context keys set by this server. To ensure that context values are cleaned up, all context properties that
         * the server set are cleared upon deinitialization. This errs on the side of clearing too much (if another
         * server set the same context keys after this server, then those keys would also be cleared when this server's
         * client deinitializes).
         */
        this.keys = new Set();
        this.messages = ContextUpdateNotification.type;
    }
    initialize() {
        this.client.onNotification(ContextUpdateNotification.type, params => {
            for (const key of Object.keys(params.updates)) {
                this.keys.add(key);
            }
            this.setContext(params);
        });
    }
    deinitialize() {
        // Clear all context properties whose keys were ever set by the server. See ContextFeature#keys.
        const params = { updates: {} };
        for (const [key] of this.keys.entries()) {
            params.updates[key] = null;
        }
        this.keys.clear();
        this.setContext(params);
    }
}
//# sourceMappingURL=context.js.map