import { BehaviorSubject } from 'rxjs';
import uuidv4 from 'uuid/v4';
import { TextDocumentPublishDecorationsNotification } from '../../protocol/decoration';
import { ensure, Feature } from './common';
/**
 * Support for text document decorations published by the server (textDocument/publishDecorations notifications
 * from the server).
 */
export class TextDocumentDecorationFeature extends Feature {
    constructor(client, registry) {
        super(client);
        this.registry = registry;
        /** Map of document URI to its decorations (last published by the server). */
        this.decorations = new Map();
        this.messages = TextDocumentPublishDecorationsNotification.type;
    }
    fillClientCapabilities(capabilities) {
        ensure(capabilities, 'decoration');
    }
    initialize(capabilities) {
        if (!capabilities.decorationProvider) {
            return;
        }
        this.register(this.messages, { id: uuidv4(), registerOptions: undefined });
        // TODO(sqs): no way to unregister this
        this.client.onNotification(TextDocumentPublishDecorationsNotification.type, params => {
            this.getDecorationsSubject(params.textDocument, params.decorations);
        });
    }
    registerProvider() {
        const client = this.client;
        const provideTextDocumentDecoration = textDocument => this.getDecorationsSubject(textDocument);
        const middleware = client.options.middleware.provideTextDocumentDecoration;
        return this.registry.registerProvider(undefined, (textDocument) => middleware
            ? middleware(textDocument, provideTextDocumentDecoration)
            : provideTextDocumentDecoration(textDocument));
    }
    getDecorationsSubject(textDocument, value) {
        let subject = this.decorations.get(textDocument.uri);
        if (!subject) {
            subject = new BehaviorSubject(value || null);
            this.decorations.set(textDocument.uri, subject);
        }
        if (value !== undefined) {
            subject.next(value);
        }
        return subject;
    }
}
//# sourceMappingURL=decoration.js.map