import uuidv4 from 'uuid/v4';
import { MarkupKind } from 'vscode-languageserver-types';
import { HoverRequest, } from '../../protocol';
import { ensure, Feature } from './common';
/**
 * Support for hover messages (textDocument/hover requests to the server).
 */
export class TextDocumentHoverFeature extends Feature {
    constructor(client, registry) {
        super(client);
        this.registry = registry;
        this.messages = HoverRequest.type;
    }
    fillClientCapabilities(capabilities) {
        const hoverCapability = ensure(ensure(capabilities, 'textDocument'), 'hover');
        hoverCapability.dynamicRegistration = true;
        hoverCapability.contentFormat = [MarkupKind.Markdown, MarkupKind.PlainText];
    }
    initialize(capabilities, documentSelector) {
        if (!capabilities.hoverProvider || !documentSelector) {
            return;
        }
        this.register(this.messages, {
            id: uuidv4(),
            registerOptions: { documentSelector },
        });
    }
    registerProvider(options) {
        const client = this.client;
        const provideTextDocumentHover = params => client.sendRequest(HoverRequest.type, params);
        const middleware = client.options.middleware.provideTextDocumentHover;
        return this.registry.registerProvider(options, (params) => middleware ? middleware(params, provideTextDocumentHover) : provideTextDocumentHover(params));
    }
}
//# sourceMappingURL=hover.js.map