import { Unsubscribable } from 'rxjs';
import { Location } from 'vscode-languageserver-types';
import { ProvideTextDocumentLocationSignature } from '../../environment/providers/location';
import { FeatureProviderRegistry } from '../../environment/providers/registry';
import { ClientCapabilities, ReferenceParams, ServerCapabilities, TextDocumentPositionParams, TextDocumentRegistrationOptions } from '../../protocol';
import { DocumentSelector } from '../../types/document';
import { NextSignature } from '../../types/middleware';
import { Client } from '../client';
import { Middleware } from '../middleware';
import { Feature } from './common';
export declare type ProvideTextDocumentLocationMiddleware<P extends TextDocumentPositionParams = TextDocumentPositionParams, L extends Location = Location> = NextSignature<P, Promise<L | L[] | null>>;
/**
 * Support for requests that retrieve a list of locations (e.g., textDocument/definition,
 * textDocument/implementation, and textDocument/typeDefinition).
 */
export declare abstract class TextDocumentLocationFeature<P extends TextDocumentPositionParams = TextDocumentPositionParams, L extends Location = Location> extends Feature<TextDocumentRegistrationOptions> {
    private registry;
    constructor(client: Client, registry: FeatureProviderRegistry<TextDocumentRegistrationOptions, ProvideTextDocumentLocationSignature<P, L>>);
    /** Override to modify the client capabilities object before sending to report support for this feature. */
    abstract fillClientCapabilities(capabilities: ClientCapabilities): void;
    /** Override to compute whether the server capabilities report support for this feature. */
    protected abstract isSupported(capabilities: ServerCapabilities): boolean;
    /** Override to return the middleware for this feature. */
    protected abstract getMiddleware?(midleware: Middleware): ProvideTextDocumentLocationMiddleware<P, L> | undefined;
    initialize(capabilities: ServerCapabilities, documentSelector: DocumentSelector): void;
    protected registerProvider(options: TextDocumentRegistrationOptions): Unsubscribable;
}
/**
 * Support for definition requests (textDocument/definition requests to the server).
 */
export declare class TextDocumentDefinitionFeature extends TextDocumentLocationFeature {
    readonly messages: import("../../jsonrpc2/messages").RequestType<TextDocumentPositionParams, import("vscode-languageserver-types").Definition, void, TextDocumentRegistrationOptions, string>;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    protected isSupported(capabilities: ServerCapabilities): boolean;
    protected getMiddleware(middleware: Middleware): ProvideTextDocumentLocationMiddleware<TextDocumentPositionParams, Location> | undefined;
}
/**
 * Support for implementation requests (textDocument/implementation requests to the server).
 */
export declare class TextDocumentImplementationFeature extends TextDocumentLocationFeature {
    readonly messages: import("../../jsonrpc2/messages").RequestType<TextDocumentPositionParams, import("vscode-languageserver-types").Definition, void, TextDocumentRegistrationOptions, string>;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    protected isSupported(capabilities: ServerCapabilities): boolean;
    protected getMiddleware(middleware: Middleware): ProvideTextDocumentLocationMiddleware<TextDocumentPositionParams, Location> | undefined;
}
/**
 * Support for type definition requests (textDocument/typeDefinition requests to the server).
 */
export declare class TextDocumentTypeDefinitionFeature extends TextDocumentLocationFeature {
    readonly messages: import("../../jsonrpc2/messages").RequestType<TextDocumentPositionParams, import("vscode-languageserver-types").Definition, void, TextDocumentRegistrationOptions, string>;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    protected isSupported(capabilities: ServerCapabilities): boolean;
    protected getMiddleware(middleware: Middleware): ProvideTextDocumentLocationMiddleware<TextDocumentPositionParams, Location> | undefined;
}
/**
 * Support for references requests (textDocument/references requests to the server).
 */
export declare class TextDocumentReferencesFeature extends TextDocumentLocationFeature<ReferenceParams, Location> {
    readonly messages: import("../../jsonrpc2/messages").RequestType<ReferenceParams, Location[] | null, void, TextDocumentRegistrationOptions, string>;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    protected isSupported(capabilities: ServerCapabilities): boolean;
    protected getMiddleware(middleware: Middleware): ProvideTextDocumentLocationMiddleware<ReferenceParams> | undefined;
}
