import { ShowInputRequest, ShowMessageNotification, ShowMessageRequest, } from '../../protocol';
/**
 * Support for server messages intended for display to the user (window/showMessages notifications and
 * window/showMessageRequest requests from the server).
 */
export class WindowShowMessageFeature {
    constructor(client, 
    /** Called when the client receives a window/showMessage notification. */
    showMessage, 
    /**
     * Called when the client receives a window/showMessageRequest request and expected to return a promise
     * that resolves to the selected action.
     */
    showMessageRequest, 
    /**
     * Called when the client receives a window/showInput request and expected to return a promise that
     * resolves to the user's input.
     */
    showInput) {
        this.client = client;
        this.showMessage = showMessage;
        this.showMessageRequest = showMessageRequest;
        this.showInput = showInput;
    }
    initialize() {
        // TODO(sqs): no way to unregister these
        this.client.onNotification(ShowMessageNotification.type, this.showMessage);
        this.client.onRequest(ShowMessageRequest.type, this.showMessageRequest);
        this.client.onRequest(ShowInputRequest.type, this.showInput);
    }
}
//# sourceMappingURL=message.js.map