import { Observable } from 'rxjs';
import { TextDocument, TextDocumentItem } from 'vscode-languageserver-types';
import { MessageType as RPCMessageType, NotificationType } from '../../jsonrpc2/messages';
import { ClientCapabilities, DidCloseTextDocumentNotification, DidCloseTextDocumentParams, DidOpenTextDocumentNotification, DidOpenTextDocumentParams, ServerCapabilities, TextDocumentRegistrationOptions, TextDocumentSyncOptions } from '../../protocol';
import { DocumentSelector } from '../../types/document';
import { NextSignature } from '../../types/middleware';
import { Client } from '../client';
import { DynamicFeature, RegistrationData } from './common';
declare type CreateParamsSignature<E, P> = (data: E) => P;
export declare abstract class TextDocumentNotificationFeature<P, E> implements DynamicFeature<TextDocumentRegistrationOptions> {
    protected client: Client;
    protected observable: Observable<E>;
    protected type: NotificationType<P, TextDocumentRegistrationOptions>;
    protected middleware: NextSignature<E, void> | undefined;
    protected createParams: CreateParamsSignature<E, P>;
    protected selectorFilter?: ((selectors: IterableIterator<(string | {
        language: string;
        scheme?: string | undefined;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme: string;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme?: string | undefined;
        pattern: string;
    })[]>, data: E) => boolean) | undefined;
    private subscription;
    protected selectors: Map<string, (string | {
        language: string;
        scheme?: string | undefined;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme: string;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme?: string | undefined;
        pattern: string;
    })[]>;
    constructor(client: Client, observable: Observable<E>, type: NotificationType<P, TextDocumentRegistrationOptions>, middleware: NextSignature<E, void> | undefined, createParams: CreateParamsSignature<E, P>, selectorFilter?: ((selectors: IterableIterator<(string | {
        language: string;
        scheme?: string | undefined;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme: string;
        pattern?: string | undefined;
    } | {
        language?: string | undefined;
        scheme?: string | undefined;
        pattern: string;
    })[]>, data: E) => boolean) | undefined);
    abstract messages: RPCMessageType | RPCMessageType[];
    abstract fillClientCapabilities(capabilities: ClientCapabilities): void;
    abstract initialize(capabilities: ServerCapabilities, documentSelector: DocumentSelector | undefined): void;
    register(_message: RPCMessageType, data: RegistrationData<TextDocumentRegistrationOptions>): void;
    private callback;
    protected notificationSent(_data: E): void;
    unregister(id: string): void;
    unregisterAll(): void;
}
/**
 * Support for notifying the server of when the client opened a text document (textDocument/didOpen notifications
 * sent by the client to the server).
 */
export declare class TextDocumentDidOpenFeature extends TextDocumentNotificationFeature<DidOpenTextDocumentParams, TextDocumentItem> {
    constructor(client: Client, environmentTextDocument: Observable<Pick<TextDocument, 'uri' | 'languageId'> | null>);
    readonly messages: typeof DidOpenTextDocumentNotification.type;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(capabilities: ServerCapabilities, documentSelector: DocumentSelector): void;
}
/**
 * Support for notifying the server of when the client closed a text document (textDocument/didClose notifications
 * sent by the client to the server).
 */
export declare class TextDocumentDidCloseFeature extends TextDocumentNotificationFeature<DidCloseTextDocumentParams, TextDocumentItem> {
    constructor(client: Client, environmentTextDocument: Observable<Pick<TextDocument, 'uri' | 'languageId'> | null>);
    readonly messages: typeof DidCloseTextDocumentNotification.type;
    fillClientCapabilities(capabilities: ClientCapabilities): void;
    initialize(capabilities: ServerCapabilities, documentSelector: DocumentSelector): void;
}
export declare function resolveTextDocumentSync(value: ServerCapabilities['textDocumentSync']): TextDocumentSyncOptions | undefined;
export {};
