import { of } from 'rxjs';
import { distinctUntilChanged, map } from 'rxjs/operators';
import { isEqual } from '../util';
import { EMPTY_CONTEXT } from './context/context';
/** An empty CXP environment. */
export const EMPTY_ENVIRONMENT = {
    root: null,
    component: null,
    extensions: null,
    configuration: { merged: {} },
    context: EMPTY_CONTEXT,
};
/** An ObservableEnvironment that always represents the empty environment and never emits changes. */
export const EMPTY_OBSERVABLE_ENVIRONMENT = {
    environment: of(EMPTY_ENVIRONMENT),
    root: of(null),
    component: of(null),
    textDocument: of(null),
    configuration: of({}),
    context: of(EMPTY_CONTEXT),
};
/**
 * Helper function for creating an ObservableEnvironment from the raw environment Observable.
 *
 * @template X extension type
 * @template C configuration cascade type
 */
export function createObservableEnvironment(environment) {
    const root = environment.pipe(map(({ root }) => root), distinctUntilChanged());
    const component = environment.pipe(map(({ component }) => component), distinctUntilChanged((a, b) => isEqual(a, b)));
    const textDocument = component.pipe(map(component => (component ? component.document : null)), distinctUntilChanged((a, b) => isEqual(a, b)));
    const configuration = environment.pipe(map(({ configuration }) => configuration), distinctUntilChanged((a, b) => isEqual(a, b)));
    const context = environment.pipe(map(({ context }) => context), distinctUntilChanged((a, b) => isEqual(a, b)));
    return {
        environment,
        root,
        component,
        textDocument,
        configuration,
        context,
    };
}
//# sourceMappingURL=environment.js.map