import { combineLatest } from 'rxjs';
import { map, switchMap } from 'rxjs/operators';
import { FeatureProviderRegistry } from './registry';
import { flattenAndCompact } from './util';
/** Provides text document decorations from all extensions. */
export class TextDocumentDecorationProviderRegistry extends FeatureProviderRegistry {
    getDecorations(params) {
        return getDecorations(this.providers, params);
    }
}
/**
 * Returns an observable that emits all decorations whenever any of the last-emitted set of providers emits
 * decorations.
 *
 * Most callers should use TextDocumentDecorationProviderRegistry, which uses the registered decoration providers.
 */
export function getDecorations(providers, params) {
    return providers
        .pipe(switchMap(providers => {
        if (providers.length === 0) {
            return [null];
        }
        return combineLatest(providers.map(provider => provider(params)));
    }))
        .pipe(map(flattenAndCompact));
}
//# sourceMappingURL=decoration.js.map