import { combineLatest, from } from 'rxjs';
import { map, switchMap } from 'rxjs/operators';
import { HoverMerged } from '../../types/hover';
import { FeatureProviderRegistry } from './registry';
/** Provides hovers from all extensions. */
export class TextDocumentHoverProviderRegistry extends FeatureProviderRegistry {
    getHover(params) {
        return getHover(this.providers, params);
    }
}
/**
 * Returns an observable that emits all providers' hovers whenever any of the last-emitted set of providers emits
 * hovers.
 *
 * Most callers should use TextDocumentHoverProviderRegistry's getHover method, which uses the registered hover
 * providers.
 */
export function getHover(providers, params) {
    return providers
        .pipe(switchMap(providers => {
        if (providers.length === 0) {
            return [[null]];
        }
        return combineLatest(providers.map(provider => from(provider(params))));
    }))
        .pipe(map(HoverMerged.from));
}
//# sourceMappingURL=hover.js.map