import { BehaviorSubject } from 'rxjs';
import { DidCloseTextDocumentNotification, DidOpenTextDocumentNotification, ShowInputRequest, TextDocumentPublishDecorationsNotification, } from '../../protocol';
class ExtWindows extends BehaviorSubject {
    constructor(ext) {
        super([
            {
                isActive: true,
                activeComponent: null,
            },
        ]);
        this.ext = ext;
        this[Symbol.observable] = () => this;
        // Track last-opened text document.
        ext.rawConnection.onNotification(DidOpenTextDocumentNotification.type, params => {
            this.next([Object.assign({}, this.value[0], { activeComponent: { isActive: true, resource: params.textDocument.uri } })]);
        });
        ext.rawConnection.onNotification(DidCloseTextDocumentNotification.type, params => {
            if (this.active &&
                this.active.activeComponent &&
                this.active.activeComponent.resource &&
                this.active.activeComponent.resource === params.textDocument.uri) {
                this.next([Object.assign({}, this.value[0], { activeComponent: null })]);
            }
        });
    }
    get all() {
        return this.value;
    }
    get active() {
        return this.value.find(({ isActive }) => isActive) || null;
    }
    showInputBox(message, defaultValue) {
        return this.ext.rawConnection.sendRequest(ShowInputRequest.type, { message, defaultValue });
    }
    setDecorations(resource, decorations) {
        return this.ext.rawConnection.sendNotification(TextDocumentPublishDecorationsNotification.type, {
            textDocument: resource,
            decorations,
        });
    }
}
/**
 * Creates the CXP extension API's {@link CXP#windows} value.
 *
 * @param ext The CXP extension API handle.
 * @return The {@link CXP#windows} value.
 */
export function createExtWindows(ext) {
    return new ExtWindows(ext);
}
//# sourceMappingURL=windows.js.map