import { Emitter, Event } from './events';
import { NotificationType } from './messages';
export var CancelNotification;
(function (CancelNotification) {
    CancelNotification.type = new NotificationType('$/cancelRequest');
})(CancelNotification || (CancelNotification = {}));
export var CancellationToken;
(function (CancellationToken) {
    CancellationToken.None = Object.freeze({
        isCancellationRequested: false,
        onCancellationRequested: Event.None,
    });
    CancellationToken.Cancelled = Object.freeze({
        isCancellationRequested: true,
        onCancellationRequested: Event.None,
    });
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unnecessary-qualifier
            (candidate === CancellationToken.None ||
                // tslint:disable-next-line:no-unnecessary-qualifier
                candidate === CancellationToken.Cancelled ||
                (typeof candidate.isCancellationRequested === 'boolean' && !!candidate.onCancellationRequested)));
    }
    CancellationToken.is = is;
})(CancellationToken || (CancellationToken = {}));
const shortcutEvent = Object.freeze((callback, context) => {
    const handle = setTimeout(callback.bind(context), 0);
    return {
        unsubscribe() {
            clearTimeout(handle);
        },
    };
});
class MutableToken {
    constructor() {
        this._isCancelled = false;
    }
    cancel() {
        if (!this._isCancelled) {
            this._isCancelled = true;
            if (this._emitter) {
                this._emitter.fire(undefined);
                this._emitter = undefined;
            }
        }
    }
    get isCancellationRequested() {
        return this._isCancelled;
    }
    get onCancellationRequested() {
        if (this._isCancelled) {
            return shortcutEvent;
        }
        if (!this._emitter) {
            this._emitter = new Emitter();
        }
        return this._emitter.event;
    }
}
export class CancellationTokenSource {
    get token() {
        if (!this._token) {
            // be lazy and create the token only when
            // actually needed
            this._token = new MutableToken();
        }
        return this._token;
    }
    cancel() {
        if (!this._token) {
            // save an object by returning the default
            // cancelled token when cancellation happens
            // before someone asks for the token
            this._token = CancellationToken.Cancelled;
        }
        else {
            ;
            this._token.cancel();
        }
    }
    unsubscribe() {
        this.cancel();
    }
}
//# sourceMappingURL=cancel.js.map