import { Unsubscribable } from 'rxjs';
import { CancellationToken } from './cancel';
import { ConnectionStrategy } from './connectionStrategy';
import { Event } from './events';
import { GenericNotificationHandler, GenericRequestHandler, NotificationHandler, RequestHandler, StarNotificationHandler, StarRequestHandler } from './handlers';
import { LinkedMap } from './linkedMap';
import { Message, NotificationMessage, NotificationType, RequestType } from './messages';
import { Trace, Tracer } from './trace';
import { MessageReader, MessageWriter } from './transport';
export interface Logger {
    error(message: string): void;
    warn(message: string): void;
    info(message: string): void;
    log(message: string): void;
}
export declare const NullLogger: Logger;
export declare enum ConnectionErrors {
    /**
     * The connection is closed.
     */
    Closed = 1,
    /**
     * The connection got unsubscribed (i.e., disposed).
     */
    Unsubscribed = 2,
    /**
     * The connection is already in listening mode.
     */
    AlreadyListening = 3
}
export declare class ConnectionError extends Error {
    readonly code: ConnectionErrors;
    constructor(code: ConnectionErrors, message: string);
}
export declare type MessageQueue = LinkedMap<string, Message>;
export interface MessageConnection extends Unsubscribable {
    sendRequest<P, R, E, RO>(type: RequestType<P, R, E, RO>, params: P, token?: CancellationToken): Promise<R>;
    sendRequest<R>(method: string, ...params: any[]): Promise<R>;
    onRequest<P, R, E, RO>(type: RequestType<P, R, E, RO>, handler: RequestHandler<P, R, E>): void;
    onRequest<R, E>(method: string, handler: GenericRequestHandler<R, E>): void;
    onRequest(handler: StarRequestHandler): void;
    sendNotification<P, RO>(type: NotificationType<P, RO>, params?: P): void;
    sendNotification(method: string, ...params: any[]): void;
    onNotification<P, RO>(type: NotificationType<P, RO>, handler: NotificationHandler<P>): void;
    onNotification(method: string, handler: GenericNotificationHandler): void;
    onNotification(handler: StarNotificationHandler): void;
    trace(value: Trace, tracer: Tracer, sendNotification?: boolean): void;
    onError: Event<[Error, Message | undefined, number | undefined]>;
    onClose: Event<void>;
    onUnhandledNotification: Event<NotificationMessage>;
    listen(): void;
    onUnsubscribe: Event<void>;
}
export interface MessageTransports {
    reader: MessageReader;
    writer: MessageWriter;
}
export declare function createMessageConnection(transports: MessageTransports, logger?: Logger, strategy?: ConnectionStrategy): MessageConnection;
