import { CancellationToken } from '../cancel';
import { MessageConnection } from '../connection';
import { Emitter } from '../events';
import { GenericNotificationHandler, GenericRequestHandler, StarNotificationHandler, StarRequestHandler } from '../handlers';
import { Message, MessageType, NotificationMessage, NotificationType, RequestType } from '../messages';
import { Trace, Tracer } from '../trace';
/**
 * A mock implementation of {@link MessageConnection} for use in tests.
 */
export declare class MockMessageConnection implements MessageConnection {
    /**
     * Messages sent by calls to {@link MockMessageConnection#sendRequest} or
     * {@link MockMessageConnection#sendNotification}.
     */
    sentMessages: {
        method: string;
        params?: any;
    }[];
    /**
     * Message handlers registered by calls to {@link MockMessageConnection#onRequest} or
     * {@link MockMessageConnection#onNotification}.
     */
    registeredHandlers: Map<string, GenericNotificationHandler | GenericRequestHandler<any, any>>;
    /**
     * Mock responses that are returned as results from {@link MockMessageConnection#sendRequest}.
     */
    mockResults: Map<string, any>;
    /**
     * Simulates receiving the given request by calling the handler registered for it.
     *
     * @return The result returned by the request handler.
     */
    recvRequest<P, R, E, RO>(type: RequestType<P, R, E, RO>, params: P): Promise<R>;
    recvRequest<R>(method: string, params: any): Promise<R>;
    /**
     * Simulates receiving the given notification by calling the handler registered for it.
     */
    recvNotification<P, RO>(type: NotificationType<P, RO>, params: P): void;
    recvNotification<R>(method: string, params: any): void;
    sendRequest(type: string | MessageType, params: any, token?: CancellationToken): Promise<any>;
    sendNotification(type: string | MessageType, params: any): void;
    onRequest(type: string | MessageType, handler: GenericRequestHandler<any, any>): void;
    onRequest(handler: StarRequestHandler): void;
    onNotification(method: string | MessageType, handler: GenericNotificationHandler): void;
    onNotification(handler: StarNotificationHandler): void;
    private onHandler;
    trace(value: Trace, tracer: Tracer, sendNotification?: boolean): void;
    errorEmitter: Emitter<[Error, Message | undefined, number | undefined]>;
    onError: import("../events").Event<[Error, Message | undefined, number | undefined]>;
    closeEmitter: Emitter<void>;
    onClose: import("../events").Event<void>;
    unhandledNotificationEmitter: Emitter<NotificationMessage>;
    onUnhandledNotification: import("../events").Event<NotificationMessage>;
    listen(): void;
    unsubscribeEmitter: Emitter<void>;
    onUnsubscribe: import("../events").Event<void>;
    unsubscribe(): void;
}
