import { NotificationMessage, NotificationType, RequestMessage, ResponseMessage } from '../jsonrpc2/messages';
export declare enum Trace {
    Off = 0,
    Messages = 1,
    Verbose = 2
}
export declare type TraceValues = 'off' | 'messages' | 'verbose';
export declare namespace Trace {
    function fromString(value: string): Trace;
    function toString(value: Trace): TraceValues;
}
export interface SetTraceParams {
    value: TraceValues;
}
export declare namespace SetTraceNotification {
    const type: NotificationType<SetTraceParams, void>;
}
export interface LogTraceParams {
    message: string;
    verbose?: string;
}
export declare namespace LogTraceNotification {
    const type: NotificationType<LogTraceParams, void>;
}
/** Records messages sent and received on a JSON-RPC 2.0 connection. */
export interface Tracer {
    log(message: string, details?: string): void;
    requestSent(message: RequestMessage): void;
    requestReceived(message: RequestMessage): void;
    notificationSent(message: NotificationMessage): void;
    notificationReceived(message: NotificationMessage): void;
    responseSent(message: ResponseMessage, request: RequestMessage, startTime: number): void;
    responseCanceled(message: ResponseMessage, request: RequestMessage, cancelMessage: NotificationMessage): void;
    responseReceived(message: ResponseMessage, request: RequestMessage | string, startTime: number): void;
    unknownResponseReceived(message: ResponseMessage): void;
}
/** A tracer that implements the Tracer interface with noop methods. */
export declare const noopTracer: Tracer;
/** A tracer that implements the Tracer interface with console API calls, intended for a web browser. */
export declare class BrowserConsoleTracer implements Tracer {
    private name;
    constructor(name: string);
    private prefix;
    log(message: string, details?: string): void;
    requestSent(message: RequestMessage): void;
    requestReceived(message: RequestMessage): void;
    notificationSent(message: NotificationMessage): void;
    notificationReceived(message: NotificationMessage): void;
    responseSent(message: ResponseMessage, request: RequestMessage, startTime: number): void;
    responseCanceled(_message: ResponseMessage, request: RequestMessage, _cancelMessage: NotificationMessage): void;
    responseReceived(message: ResponseMessage, request: RequestMessage | string, startTime: number): void;
    unknownResponseReceived(message: ResponseMessage): void;
}
