import { isFunction } from '../util';
import { Emitter } from './events';
export var MessageReader;
(function (MessageReader) {
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.listen) &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.unsubscribe) &&
            isFunction(candidate.onError) &&
            isFunction(candidate.onClose) &&
            isFunction(candidate.onPartialMessage));
    }
    MessageReader.is = is;
})(MessageReader || (MessageReader = {}));
export class AbstractMessageReader {
    constructor() {
        this.errorEmitter = new Emitter();
        this.closeEmitter = new Emitter();
        this.partialMessageEmitter = new Emitter();
    }
    unsubscribe() {
        this.errorEmitter.unsubscribe();
        this.closeEmitter.unsubscribe();
    }
    get onError() {
        return this.errorEmitter.event;
    }
    fireError(error) {
        this.errorEmitter.fire(this.asError(error));
    }
    get onClose() {
        return this.closeEmitter.event;
    }
    fireClose() {
        this.closeEmitter.fire(undefined);
    }
    get onPartialMessage() {
        return this.partialMessageEmitter.event;
    }
    firePartialMessage(info) {
        this.partialMessageEmitter.fire(info);
    }
    asError(error) {
        if (error instanceof Error) {
            return error;
        }
        return new Error(`Reader received error. Reason: ${typeof error.message === 'string' ? error.message : 'unknown'}`);
    }
}
export var MessageWriter;
(function (MessageWriter) {
    function is(value) {
        const candidate = value;
        return (candidate &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.unsubscribe) &&
            isFunction(candidate.onClose) &&
            isFunction(candidate.onError) &&
            // tslint:disable-next-line:no-unbound-method
            isFunction(candidate.write));
    }
    MessageWriter.is = is;
})(MessageWriter || (MessageWriter = {}));
export class AbstractMessageWriter {
    constructor() {
        this.errorEmitter = new Emitter();
        this.closeEmitter = new Emitter();
    }
    unsubscribe() {
        this.errorEmitter.unsubscribe();
        this.closeEmitter.unsubscribe();
    }
    get onError() {
        return this.errorEmitter.event;
    }
    fireError(error, message, count) {
        this.errorEmitter.fire([this.asError(error), message, count]);
    }
    get onClose() {
        return this.closeEmitter.event;
    }
    fireClose() {
        this.closeEmitter.fire(undefined);
    }
    asError(error) {
        if (error instanceof Error) {
            return error;
        }
        return new Error(`Writer received error. Reason: ${typeof error.message === 'string' ? error.message : 'unknown'}`);
    }
}
//# sourceMappingURL=transport.js.map