import { NotificationType, RequestType } from '../jsonrpc2/messages';
/**
 * The initialize request is sent from the client to the server. It is sent once as the request after starting up
 * the server. The requests parameter is of type [InitializeParams](#InitializeParams) the response if of type
 * [InitializeResult](#InitializeResult) of a Thenable that resolves to such.
 */
export var InitializeRequest;
(function (InitializeRequest) {
    InitializeRequest.type = new RequestType('initialize');
})(InitializeRequest || (InitializeRequest = {}));
/**
 * Known error codes for an `InitializeError`;
 */
export var InitializeError;
(function (InitializeError) {
    /**
     * If the protocol version provided by the client can't be handled by the server.
     * @deprecated This initialize error got replaced by client capabilities. There is
     * no version handshake in version 3.0x
     */
    InitializeError.unknownProtocolVersion = 1;
})(InitializeError || (InitializeError = {}));
/**
 * The intialized notification is sent from the client to the
 * server after the client is fully initialized and the server
 * is allowed to send requests from the server to the client.
 */
export var InitializedNotification;
(function (InitializedNotification) {
    InitializedNotification.type = new NotificationType('initialized');
})(InitializedNotification || (InitializedNotification = {}));
/**
 * A shutdown request is sent from the client to the server.
 * It is sent once when the client decides to shutdown the
 * server. The only notification that is sent after a shutdown request
 * is the exit event.
 */
export var ShutdownRequest;
(function (ShutdownRequest) {
    ShutdownRequest.type = new RequestType('shutdown');
})(ShutdownRequest || (ShutdownRequest = {}));
/**
 * The exit event is sent from the client to the server to
 * ask the server to exit its process.
 */
export var ExitNotification;
(function (ExitNotification) {
    ExitNotification.type = new NotificationType('exit');
})(ExitNotification || (ExitNotification = {}));
//# sourceMappingURL=initialize.js.map