import { NotificationType, RequestType } from '../jsonrpc2/messages';
/**
 * The message type
 */
export var MessageType;
(function (MessageType) {
    /**
     * An error message.
     */
    MessageType.Error = 1;
    /**
     * A warning message.
     */
    MessageType.Warning = 2;
    /**
     * An information message.
     */
    MessageType.Info = 3;
    /**
     * A log message.
     */
    MessageType.Log = 4;
})(MessageType || (MessageType = {}));
/**
 * The show message notification is sent from a server to a client to ask
 * the client to display a particular message in the user interface.
 */
export var ShowMessageNotification;
(function (ShowMessageNotification) {
    ShowMessageNotification.type = new NotificationType('window/showMessage');
})(ShowMessageNotification || (ShowMessageNotification = {}));
/**
 * The show message request is sent from the server to the client to show a message and a set of actions to the
 * user.
 */
export var ShowMessageRequest;
(function (ShowMessageRequest) {
    ShowMessageRequest.type = new RequestType('window/showMessageRequest');
})(ShowMessageRequest || (ShowMessageRequest = {}));
/**
 * The show input request is sent from the server to the client to show a message and prompt the user for input.
 */
export var ShowInputRequest;
(function (ShowInputRequest) {
    ShowInputRequest.type = new RequestType('window/showInput');
})(ShowInputRequest || (ShowInputRequest = {}));
/**
 * The log message notification is sent from the server to the client to ask
 * the client to log a particular message.
 */
export var LogMessageNotification;
(function (LogMessageNotification) {
    LogMessageNotification.type = new NotificationType('window/logMessage');
})(LogMessageNotification || (LogMessageNotification = {}));
//# sourceMappingURL=message.js.map