import { MarkedString, MarkupContent, Range } from 'vscode-languageserver-types';
export var HoverMerged;
(function (HoverMerged) {
    /** Create a merged hover from the given individual hovers. */
    function from(values) {
        const contents = [];
        let range;
        for (const result of values) {
            if (result) {
                if (Array.isArray(result.contents)) {
                    contents.push(...result.contents);
                }
                else {
                    contents.push(result.contents);
                }
                if (result.range && !range) {
                    range = result.range;
                }
            }
        }
        return contents.length === 0 ? null : range ? { contents, range } : { contents };
    }
    HoverMerged.from = from;
    /** Reports whether the value conforms to the HoverMerged interface. */
    function is(value) {
        // Based on Hover.is from vscode-languageserver-types.
        return (value !== null &&
            typeof value === 'object' &&
            Array.isArray(value.contents) &&
            // tslint:disable-next-line:deprecation
            value.contents.every(c => MarkupContent.is(c) || MarkedString.is(c)) &&
            (value.range === undefined || Range.is(value.range)));
    }
    HoverMerged.is = is;
})(HoverMerged || (HoverMerged = {}));
//# sourceMappingURL=hover.js.map